"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var namingService_1 = require("../../services/namingService");
var storageAccount_1 = require("./storageAccount");
describe("Storage Account Resource", function () {
    var config = {
        functions: [],
        plugins: [],
        provider: {
            prefix: "sls",
            name: "azure",
            region: "westus",
            stage: "dev",
        },
        service: "test-api"
    };
    it("Generates safe storage account name with short parts", function () {
        var testConfig = __assign({}, config, { service: "test-api" });
        var result = storageAccount_1.StorageAccountResource.getResourceName(testConfig);
        assertValidStorageAccountName(testConfig, result);
        expect(result.startsWith("slswusdev")).toBe(true);
    });
    it("Generates safe storage account names with long parts", function () {
        var testConfig = __assign({}, config, { provider: __assign({}, config.provider, { prefix: "my-long-test-prefix-name", region: "Australia Southeast", stage: "development" }) });
        var result = storageAccount_1.StorageAccountResource.getResourceName(testConfig);
        assertValidStorageAccountName(testConfig, result);
        expect(result.startsWith("mylaussedev")).toBe(true);
    });
    it("Generating a storage account name is idempotent", function () {
        var result1 = storageAccount_1.StorageAccountResource.getResourceName(config);
        var result2 = storageAccount_1.StorageAccountResource.getResourceName(config);
        expect(result1).toEqual(result2);
    });
    it("Generates distinct account names based on region", function () {
        var regions = [
            "eastasia",
            "southeastasia",
            "centralus",
            "eastus",
            "eastus2",
            "westus",
            "northcentralus",
            "southcentralus",
            "northeurope",
            "westeurope",
            "japanwest",
            "japaneast",
            "brazilsouth",
            "australiaeast",
            "australiasoutheast",
            "southindia",
            "centralindia",
            "westindia",
            "canadacentral",
            "canadaeast",
            "uksouth",
            "ukwest",
            "westcentralus",
            "westus2",
            "koreacentral",
            "koreasouth",
            "francecentral",
            "francesouth",
            "australiacentral",
            "australiacentral2",
            "uaecentral",
            "uaenorth",
            "southafricanorth",
            "southafricawest"
        ];
        var regionConfigs = regions.map(function (region) {
            return __assign({}, config, { provider: __assign({}, config.provider, { region: region }) });
        });
        var results = {};
        regionConfigs.forEach(function (config) {
            var result = storageAccount_1.StorageAccountResource.getResourceName(config);
            assertValidStorageAccountName(config, result);
            results[result] = config;
        });
        expect(Object.keys(results)).toHaveLength(regionConfigs.length);
    });
    it("Generates distinct account names based on stage", function () {
        var stages = [
            "dev",
            "test",
            "qa",
            "uat",
            "prod",
            "preprod",
        ];
        var stageConfigs = stages.map(function (region) {
            return __assign({}, config, { provider: __assign({}, config.provider, { region: region }) });
        });
        var results = {};
        stageConfigs.forEach(function (config) {
            var result = storageAccount_1.StorageAccountResource.getResourceName(config);
            assertValidStorageAccountName(config, result);
            results[result] = config;
        });
        expect(Object.keys(results)).toHaveLength(stageConfigs.length);
    });
    function assertValidStorageAccountName(config, value) {
        expect(value.length).toBeLessThanOrEqual(24);
        expect(value.match(/[a-z0-9]/g).length).toEqual(value.length);
        expect(value).toContain(namingService_1.AzureNamingService.createShortAzureRegionName(config.provider.region));
        expect(value).toContain(createSafeString(config.provider.prefix));
        expect(value).toContain(createSafeString(config.provider.stage));
    }
    function createSafeString(value) {
        return value.replace(/\W+/g, "").toLowerCase().substr(0, 3);
    }
    ;
});
