"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var mock_fs_1 = __importDefault(require("mock-fs"));
var mockFactory_1 = require("../../../test/mockFactory");
var simpleFileTokenCache_1 = require("./simpleFileTokenCache");
describe("Simple File Token Cache", function () {
    var tokenFilePath = "slsTokenCache.json";
    var fileContent = {
        entries: [],
        subscriptions: [],
    };
    afterEach(function () {
        mock_fs_1.default.restore();
    });
    it("Creates a load file on creation if none", function () {
        mock_fs_1.default();
        var writeFileSpy = jest.spyOn(fs_1.default, "writeFileSync");
        new simpleFileTokenCache_1.SimpleFileTokenCache(tokenFilePath);
        var expected = {
            entries: [],
            subscriptions: [],
        };
        expect(writeFileSpy).toBeCalledWith(tokenFilePath, JSON.stringify(expected));
        writeFileSpy.mockRestore();
    });
    it("Load file on creation if available", function () {
        fileContent.entries = mockFactory_1.MockFactory.createTestTokenCacheEntries();
        mock_fs_1.default({
            "slsTokenCache.json": JSON.stringify(fileContent),
        });
        var readFileSpy = jest.spyOn(fs_1.default, "readFileSync");
        var tokenCache = new simpleFileTokenCache_1.SimpleFileTokenCache(tokenFilePath);
        expect(readFileSpy).toBeCalled();
        expect(tokenCache.first()).not.toBeNull();
        readFileSpy.mockRestore();
    });
    it("Saves to file after token is added", function () {
        mock_fs_1.default();
        var writeFileSpy = jest.spyOn(fs_1.default, "writeFileSync");
        var tokenCache = new simpleFileTokenCache_1.SimpleFileTokenCache(tokenFilePath);
        var testEntries = mockFactory_1.MockFactory.createTestTokenCacheEntries();
        tokenCache.add(testEntries);
        var expected = {
            entries: testEntries,
            subscriptions: [],
        };
        expect(tokenCache.isEmpty()).toBe(false);
        expect(writeFileSpy).toBeCalledWith(tokenFilePath, JSON.stringify(expected));
        writeFileSpy.mockRestore();
    });
    it("Saves to file after subscription is added", function () {
        mock_fs_1.default();
        var writeFileSpy = jest.spyOn(fs_1.default, "writeFileSync");
        var testFileCache = new simpleFileTokenCache_1.SimpleFileTokenCache(tokenFilePath);
        var testSubs = mockFactory_1.MockFactory.createTestSubscriptions();
        testFileCache.addSubs(testSubs);
        var expected = {
            entries: [],
            subscriptions: testSubs,
        };
        expect(writeFileSpy).toBeCalledWith(tokenFilePath, JSON.stringify(expected));
        writeFileSpy.mockRestore();
    });
});
